@@ -32,10 +32,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x031106
-pyqt_version_str = "3.17.6"
+pyqt_version = 0x031201
+pyqt_version_str = "3.18.1"
 
-sip_min_version = 0x040600
+sip_min_version = 0x040800
 
 
 # Try and find a Qt installation to use as the default.
@@ -100,30 +100,30 @@ def usage(rcode = 2):
     else:
         def_qt_dir = "none"
 
-    print "Usage:"
-    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-f] [-g dir] [-i] [-j #] [-k] [-l dir] [-m dir] [-n dir] [-o dir] [-q dir] [-r] [-s] [-u] [-v dir] [-w] [-y lib] option=value option+=value ..."
-    print "where:"
-    print "  -h      display this help message"
-    print "  -a tag  explicitly enable the qtpe module"
-    print "  -b dir  where pyuic and pylupdate will be installed [default %s]" % opt_pyqtbindir
-    print "  -c      concatenate each module's C/C++ source files"
-    print "  -d dir  where the PyQt modules will be installed [default %s]" % opt_pyqtmoddir
-    print "  -f      keep any existing features file (when cross-compiling) [default remove]"
-    print "  -g dir  where the Qt qconfig.h file can be found [default Qt include directory]"
-    print "  -i      enable checking of signed interpreters using the VendorID package [default disabled]"
-    print "  -j #    split the concatenated C++ source files into # pieces [default 1]"
-    print "  -k      build the PyQt modules as static libraries"
-    print "  -l dir  the directory containing the VendorID header file [default %s]" % opt_vendincdir
-    print "  -m dir  the directory containing the VendorID library [default %s]" % opt_vendlibdir
-    print "  -n dir  the directory containing the QScintilla header files [default Qt include directory]"
-    print "  -o dir  the directory containing the QScintilla library [default Qt lib directory]"
-    print "  -q dir  the root directory of the Qt installation [default %s]" % def_qt_dir
-    print "  -r      generate code with tracing enabled [default disabled]"
-    print "  -s      QScintilla is a static library and not a DLL (Windows only)"
-    print "  -u      build with debugging symbols (requires a debug build of Python on Windows"
-    print "  -v dir  where the PyQt .sip files will be installed [default %s]" % opt_pyqtsipdir
-    print "  -w      don't suppress compiler output during configuration"
-    print "  -y lib  explicitly specify the type of Qt library, either qt, qt-mt, qte, qte-mt or qtmt"
+    sys.stdout.write("Usage:\n")
+    sys.stdout.write("    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-f] [-g dir] [-i] [-j #] [-k] [-l dir] [-m dir] [-n dir] [-o dir] [-q dir] [-r] [-s] [-u] [-v dir] [-w] [-y lib] option=value option+=value ...\n")
+    sys.stdout.write("where:\n")
+    sys.stdout.write("  -h      display this help message\n")
+    sys.stdout.write("  -a tag  explicitly enable the qtpe module\n")
+    sys.stdout.write("  -b dir  where pyuic and pylupdate will be installed [default %s]\n" % opt_pyqtbindir)
+    sys.stdout.write("  -c      concatenate each module's C/C++ source files\n")
+    sys.stdout.write("  -d dir  where the PyQt modules will be installed [default %\ns]" % opt_pyqtmoddir)
+    sys.stdout.write("  -f      keep any existing features file (when cross-compiling) [default remove]\n")
+    sys.stdout.write("  -g dir  where the Qt qconfig.h file can be found [default Qt include directory]\n")
+    sys.stdout.write("  -i      enable checking of signed interpreters using the VendorID package [default disabled]\n")
+    sys.stdout.write("  -j #    split the concatenated C++ source files into # pieces [default 1]\n")
+    sys.stdout.write("  -k      build the PyQt modules as static libraries\n")
+    sys.stdout.write("  -l dir  the directory containing the VendorID header file [default %s]\n" % opt_vendincdir)
+    sys.stdout.write("  -m dir  the directory containing the VendorID library [default %s]\n" % opt_vendlibdir)
+    sys.stdout.write("  -n dir  the directory containing the QScintilla header files [default Qt include directory]\n")
+    sys.stdout.write("  -o dir  the directory containing the QScintilla library [default Qt lib directory]\n")
+    sys.stdout.write("  -q dir  the root directory of the Qt installation [default %s]\n" % def_qt_dir)
+    sys.stdout.write("  -r      generate code with tracing enabled [default disabled]\n")
+    sys.stdout.write("  -s      QScintilla is a static library and not a DLL (Windows only)\n")
+    sys.stdout.write("  -u      build with debugging symbols (requires a debug build of Python on Windows\n")
+    sys.stdout.write("  -v dir  where the PyQt .sip files will be installed [default %s]\n" % opt_pyqtsipdir)
+    sys.stdout.write("  -w      don't suppress compiler output during configuration\n")
+    sys.stdout.write("  -y lib  explicitly specify the type of Qt library, either qt, qt-mt, qte, qte-mt or qtmt\n")
 
     sys.exit(rcode)
 
@@ -1003,11 +1003,12 @@ def check_license():
             sipconfig.error("This version of PyQt and the %s edition of Qt have incompatible licenses." % qted)
 
     # Confirm the license.
-    print
-    print "Type 'L' to view the license."
-    print "Type 'yes' to accept the terms of the license."
-    print "Type 'no' to decline the terms of the license."
-    print
+    sys.stdout.write("""
+Type 'L' to view the license.
+Type 'yes' to accept the terms of the license.
+Type 'no' to decline the terms of the license.
+
+""")
 
     while 1:
         try:
@@ -1295,6 +1296,10 @@ def main(argv):
 
     argv is the list of command line arguments.
     """
+    # Check Python isn't too new.
+    if sipcfg.py_version >= 0x030000:
+        sipconfig.error("PyQt v3.x does not support Python v3.x")
+
     # Check SIP is new enough.
     if sipcfg.sip_version_str[:8] != "snapshot":
         if sipcfg.sip_version < sip_min_version:
@@ -1441,8 +1446,8 @@ if __name__ == "__main__":
     except SystemExit:
         raise
     except:
-        print \
+        sys.stderr.write(
 """An internal error occured.  Please report all the output from the program,
 including the following traceback, to support@riverbankcomputing.co.uk.
-"""
+""")
         raise
